# Python Custom Logging Module
This is a custom logging module for Python. It is a simple module that allows you to log messages to a file and/or the console. It also allows you to set the log level so that you can control which messages get logged.

## Installation
To install the module, simply copy the `logging.py` file to your project directory.
